WasmBuilderSelectSource

Struct WasmBuilderSelectSource 

pub struct WasmBuilderSelectSource(/* private fields */);
Second step of the WasmBuilder to set the source of the wasm-builder.

Implementations

Source

impl WasmBuilderSelectSource

pub fn with_wasm_builder_from_path(self, path: &'static str) -> WasmBuilder

Use the given path as source for wasm-builder.

The path must be relative and point to the directory that contains the Cargo.toml for wasm-builder.

pub fn with_wasm_builder_from_git( self, repo: &'static str, rev: &'static str, ) -> WasmBuilder

Use the given repo and rev as source for wasm-builder.

pub fn with_wasm_builder_from_crates(self, version: &'static str) -> WasmBuilder

Use the given version to fetch wasm-builder source from crates.io.

pub fn with_wasm_builder_from_crates_or_path( self, version: &'static str, path: &'static str, ) -> WasmBuilder

Use the given version to fetch wasm-builder source from crates.io or use the given path as source.

The path must be relative and point to the directory that contains the Cargo.toml for wasm-builder.

pub fn with_wasm_builder_source(self, source: WasmBuilderSource) -> WasmBuilder

Use the given source as source for wasm-builder.